Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(146)

Unified Diff: chrome/browser/prefs/pref_service_builder.h

Issue 11741003: Remove PrefServiceSimple, replacing it with PrefService and PrefRegistrySimple. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix double registration in Chrome Frame test. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/prefs/pref_service.cc ('k') | chrome/browser/prefs/pref_service_builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/prefs/pref_service_builder.h
diff --git a/chrome/browser/prefs/pref_service_builder.h b/chrome/browser/prefs/pref_service_builder.h
index 208e334feff02438b5ac5e5bdfeddba1b3ec789c..21489aee99ec8c1ff70ec2742688ffb29a52d0b7 100644
--- a/chrome/browser/prefs/pref_service_builder.h
+++ b/chrome/browser/prefs/pref_service_builder.h
@@ -10,8 +10,9 @@
#include "base/memory/ref_counted.h"
#include "base/prefs/persistent_pref_store.h"
#include "base/prefs/pref_store.h"
+#include "chrome/browser/prefs/pref_registry.h"
-class PrefServiceSimple;
+class PrefService;
namespace base {
class FilePath;
@@ -45,9 +46,9 @@ class PrefServiceBuilder {
PrefServiceBuilder& WithAsync(bool async);
- // Creates a PrefServiceSimple object initialized with the
- // parameters from this builder.
- virtual PrefServiceSimple* CreateSimple();
+ // Creates a PrefService object initialized with the parameters from
+ // this builder.
+ virtual PrefService* Create(PrefRegistry* registry);
protected:
virtual void ResetDefaultState();
« no previous file with comments | « chrome/browser/prefs/pref_service.cc ('k') | chrome/browser/prefs/pref_service_builder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698